@@ -5,6 +5,9 @@ Configuration = {
     "trace_auto_normalize_enabled": True,
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
+    "trace_ignore_url_set": [],
+    "trace_ignore_url_prefix": None,
+
 
     "query_string_enabled": False,
     "query_string_urls": "",
