@@ -41,6 +41,8 @@ class Configure(object):
                         key, value = line.split('=')
                         key = key.strip()
                         value = value.strip()
+                        if key and key.endswith("_set"):
+                            value = value.split(",")
                         cls.setProperty(key, value)
                     
                     except Exception as e:
