@@ -256,3 +256,7 @@ class DataOutputX(object):
             buffer_arr = bytearray(self.buffer.getvalue())
             buffer_arr[pos:pos + 4] = b.getvalue()
             self.buffer = io.BytesIO(buffer_arr)
+
+    def size(self):
+        return self.buffer.getbuffer().nbytes
+        
\ No newline at end of file
