@@ -18,6 +18,7 @@ class TraceContextManager(object):
     local = threading.local()
     node = uuid.getnode()
     clock_seq = random.randrange(1 << 14)
+    dbpool = LinkedMap()
     
     @classmethod
     def keys(cls):
@@ -134,4 +135,54 @@ class TraceContextManager(object):
             current = greenlet.getcurrent()
             if current is not None and current.parent:
                 return id(current.parent)
-        return threading.get_ident()
\ No newline at end of file
+        return threading.get_ident()
+
+    @classmethod
+    def getDBConnPool(cls):
+        d = dict()
+        keyvalueEnumer = cls.dbpool.entries()
+        while keyvalueEnumer.hasMoreElements():
+            en = keyvalueEnumer.nextElement()
+            d[en.getKey()] = en.getValue()
+        return d
+
+    @classmethod
+    def addDBPoolIdle(cls, url, isCheckIn = False):
+        if not cls.dbpool.containsKey(url):
+            cls.dbpool.put(url,[0, 0])
+        
+        newstat = cls.dbpool.get(url)
+        if isCheckIn:
+            newstat[0] -= 1
+            if newstat[0] < 0:
+                newstat[0] = 0
+        newstat[1] += 1
+
+        cls.dbpool.put(url, newstat)
+        return 
+        
+    @classmethod
+    def removeDBPoolIdle(cls, url):
+        if not cls.dbpool.containsKey(url):
+            cls.dbpool.put(url,[0, 0])
+            return
+        newstat = cls.dbpool.get(url)
+        if newstat:
+            newstat[1] -= 1
+            if newstat[1] < 0:
+                newstat[1] = 0
+            cls.dbpool.put(url, newstat)
+
+    @classmethod
+    def addDBPoolActive(cls, url):
+        if not cls.dbpool.containsKey(url):
+            cls.dbpool.put(url,[0, 0])
+        newstat = cls.dbpool.get(url)
+        if newstat:
+            newstat[0] += 1
+            newstat[1] -= 1
+            if newstat[1] < 0:
+                newstat[1] = 0
+            cls.dbpool.put(url, newstat)
+        return 
+
