@@ -38,8 +38,6 @@ class _ImportHookLoader(object):
         module = sys.modules[fullname]
         return load_module(module, fullname)
 
-
-
 class _ImportHookChainedLoader(object):
     def __init__(self, loader):
         self.loader = loader
@@ -48,17 +46,18 @@ class _ImportHookChainedLoader(object):
         module = self.loader.load_module(fullname)
         return load_module(module, fullname)
 
-
 class ImportFinder(object):
     def __init__(self):
         self._hooks = {}
     
     def find_module(self, fullname, path=None):
-        if fullname in self._hooks \
+        if fullname not in IMPORT_HOOKS \
                 or fullname.startswith('whatap') \
                 or fullname.startswith('pip'):
             return None
-        
+
+        if fullname in self._hooks:
+            return None
         self._hooks[fullname] = True
         
         # if conf.dev:
